==> herrie-0.1.tar.gz: herrie-0.1/src/audio/audio.h <==
/*
 * Copyright (c) 2006 Ed Schouten <ed@fxq.nl>
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $Id: audio.h 476 2006-08-01 06:26:05Z ed $
 */
/**
 * @file audio/audio.h
 */

#ifndef _AUDIO_AUDIO_H_
#define _AUDIO_AUDIO_H_

#include <stdio.h>

#include <sys/types.h>

struct audio_file;
struct audio_driver;

/**
 * @brief Audio driver containg its type and functions to open, close and read
 * 	the driver.
 */
struct audio_driver {
	/**
	 * @brief The driver's type.
	 */
	char *type;
	/**
	 * @brief The driver's open call.
	 */
	int (*open)(struct audio_file *fd);
	/**
	 * @brief The driver's close call.
	 */
	void (*close)(struct audio_file *fd);
	/**
	 * @brief The driver's read call.
	 */
	size_t (*read)(struct audio_file *fd, void *buf);
	/**
	 * @brief The driver's seek call.
	 */
	void (*seek)(struct audio_file *fd, double len);
};

/**
 * @brief The data needed about an audio file.
 */
struct audio_file {
	/**
	 * @brief The FILE pointer for the file.
	 */
	FILE *fp;

	/**
	 * @brief An audio driver for opening, closing and reading
	 * 	the audio file.
	 */
	struct audio_driver *drv;
	/**
	 * @brief Extra information that might be needed.
	 */
	void *drv_data;

	/**
	 * @brief The file's sample rate.
	 */
	long srate;

	/**
	 * @brief The file's length in seconds.
	 */
	double time_len;
	/**
	 * @brief Position we are at in the file in seconds.
	 */
	double time_cur;

	/**
	 * @brief Information about the song acquired from the file
	 */
	struct {
		/**
		 * @brief Name of the artist
		 */
		char *artist;
		/**
		 * @brief Name of the song
		 */
		char *title;
		/**
		 * @brief Name of the album
		 */
		char *album;
	} tag;
};

/**
 * @brief Print supported formats.
 */
void audio_dump_formats(void);

/**
 * @brief Fill an audio_file struct with the appropiate information
 * 	and function calls, and open the file handle.
 */
struct audio_file *audio_open(const char *filename);
/**
 * @brief Clean up the given audio_file struct and close the file handle.
 */
void audio_close(struct audio_file *fd);

/**
 * @brief Call the read function in the audio_file struct.
 */
#define audio_read(fd,buf) (fd->drv->read(fd,buf))

/**
 * @brief Call the seek function in the audio_file struct if available.
 */
void audio_seek(struct audio_file *fd, double len);

#endif /* !_AUDIO_AUDIO_H_ */

==> herrie-0.6.tar.gz: herrie-0.6/src/audio/audio.h <==
/*
 * Copyright (c) 2006 Ed Schouten <ed@fxq.nl>
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $Id$
 */
/**
 * @file audio/audio.h
 */

#ifndef _AUDIO_AUDIO_H_
#define _AUDIO_AUDIO_H_

#include <stdio.h>

#include <sys/types.h>

struct audio_driver;

/**
 * @brief The data needed about an audio file.
 */
struct audio_file {
	/**
	 * @brief The FILE pointer for the file.
	 */
	FILE *fp;

	/**
	 * @brief An audio driver for opening, closing and reading
	 * 	the audio file.
	 */
	struct audio_driver *drv;
	/**
	 * @brief Extra information that might be needed.
	 */
	void *drv_data;

	/**
	 * @brief The file's sample rate.
	 */
	long srate;

	/**
	 * @brief The number of audio channels.
	 */
	long channels;

	/**
	 * @brief The file's length in seconds.
	 */
	double time_len;
	/**
	 * @brief Position we are at in the file in seconds.
	 */
	double time_cur;

	/**
	 * @brief Information about the song acquired from the file
	 */
	struct {
		/**
		 * @brief Name of the artist
		 */
		char *artist;
		/**
		 * @brief Name of the song
		 */
		char *title;
		/**
		 * @brief Name of the album
		 */
		char *album;
	} tag;

#ifdef BUILD_SCROBBLER
	/**
	 * @brief Indicator whether the scrobbler code is done with the
	 *        song.
	 */
	char _scrobbler_done;
#endif /* BUILD_SCROBBLER */
};

/**
 * @brief Fill an audio_file struct with the appropiate information
 * 	and function calls, and open the file handle.
 */
struct audio_file *audio_open(const char *filename);
/**
 * @brief Clean up the given audio_file struct and close the file handle.
 */
void audio_close(struct audio_file *fd);

/**
 * @brief Call the read function in the audio_file struct.
 */
size_t audio_read(struct audio_file *fd, void *buf);

/**
 * @brief Call the seek function in the audio_file struct if available.
 */
void audio_seek(struct audio_file *fd, double len);

#endif /* !_AUDIO_AUDIO_H_ */
